<?php
namespace Concrete\Package\WebhappPixabay\Block\PixabayImage;

use File;
use Package;
use \Concrete\Core\Block\BlockController;
use \Concrete\Core\File\Importer;
use \Concrete\Core\File\Service\File as FileHelper;
use \Concrete\Core\Validation\SanitizeService;
use \Concrete\Core\Asset\AssetList;
use \Concrete\Core\Tree\Node\Type\FileFolder;
use \Concrete\Core\Support\Facade\Application as FacadeApplication;

/*
 * Created by Jozzeh, Developer @ webhapp
 * Easily search and import pixabay images
 */

defined('C5_EXECUTE') or die("Access Denied.");

class Controller extends BlockController
{
    protected $btTable = 'btPixabayImage';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "400";
    protected $btCacheBlockOutput = true;
    protected $btCacheBlockRecord = true;
    protected $btDefaultSet = 'multimedia';
	
	public function on_start()
    {
		$pkg = Package::getByHandle('webhapp_pixabay');
        $al = AssetList::getInstance();
        $al->register('css', 'addeditcss', 'blocks/pixabay_image/pixaedit/add.css', array('version' => 1, 'minify' => false, 'combine' => false), $pkg);

        $al->registerGroup('pixabaycssjs',
            array(
                array('css', 'addeditcss'),
            )
        );
    }

    public function getBlockTypeDescription()
    {
        return t("Search and import pixabay images.");
    }

    public function getBlockTypeName()
    {
        return t("Pixabay Image");
    }

    public function add()
    {
        $this->requireAsset('pixabaycssjs');
    }

    public function edit()
    {
        $this->requireAsset('pixabaycssjs');
        $fileObj = File::getByID($this->fID);
        if (is_object($fileObj)) {
            $this->set('f', $fileObj);
            $this->set('imgAlt', $this->imgAlt);
            $this->set('imgTags', $this->imgTags);
        }
    }

    public function view()
    {
        $fileObj = File::getByID($this->fID);
        if (is_object($fileObj)) {
            $this->set('f', $fileObj);
            $this->set('imgAlt', $this->imgAlt);
        } else {
            $this->set('pixaerror', t('An error has occurred retrieving the image. '));
        }
    }

    public function validate($args)
    {
		$app = FacadeApplication::getFacadeApplication();
        $error = $app->make('helper/validation/error');
        $fileUrl = SanitizeService::sanitizeURL($args['fileUrl']);
        $fID = SanitizeService::sanitizeInt($args['fID']);

        if (!$fileUrl && !$fID) {
            $error->add(t('A Pixabay image must be selected...'));
        }

        return $error;
    }

    public function save($args)
    {
        if (empty($args['fID'])) {
            //if a new file is selected
            $fileUrl = SanitizeService::sanitizeURL($args['fileUrl']);
            if (strpos($fileUrl, '.jpg')) {
                $fileName = urlencode($args['question']) . '.jpg';
            } else if (strpos($fileUrl, '.png')) {
                $fileName = urlencode($args['question']) . '.png';
            } else if (strpos($fileUrl, '.gif')) {
                $fileName = urlencode($args['question']) . '.gif';
            } else if (strpos($fileUrl, '.svg')) {
                $fileName = urlencode($args['question']) . '.svg';
            } else {
                $fileName = urlencode($args['question']) . '.jpg';
            }
            

            $fileContent = FileHelper::getContents($fileUrl);
            if ($fileContent != false) {
                FileHelper::append(FileHelper::getTemporaryDirectory() . '/' . $fileName, $fileContent);

                $folder = FileFolder::getNodeByName("pixabay_import");
                if(!is_object($folder)){
                    $folder = false;
                }

                $importer = new Importer();
                $result = $importer->import(FileHelper::getTemporaryDirectory() . '/' . $fileName, $fileName, $folder);

                FileHelper::clear(FileHelper::getTemporaryDirectory() . '/' . $fileName);
                if (is_object($result)) {
                    $altImg = $args['imgAlt'];
                    $imgTags = $args['question'];
                    $args = array();
                    $args['fID'] = SanitizeService::sanitizeInt($result->getFileID());
                    $args['imgAlt'] = SanitizeService::sanitizeString($altImg);
                    $args['imgTags'] = SanitizeService::sanitizeString($imgTags);
                    parent::save($args);
                } else {
                    $error = $result;
                    echo $error;
                    exit;
                }
            } else {
                $error = "Error retrieving file! Please check you have apache mod_ssl, php_curl and php_openssl enabled";
                echo $error;
                exit;
            }

        } else {
            //if no file was selected, but description was updated...
            $fID = $args['fID'];
            $altImg = $args['altImg'];
            $args['fID'] = SanitizeService::sanitizeInt($fID);
            $args['altImg'] = SanitizeService::sanitizeString($altImg);
            parent::save($args);
        }
    }
}
